@@ -23,11 +23,13 @@ class OperationFailed(WebdavException):
         self.actual_code = actual_code
         operation_name = self._OPERATIONS[method]
         self.reason = 'Failed to {operation_name} "{path}"'.format(**locals())
-        expected_code_str, actual_code_str = HTTP_CODES[expected_code], HTTP_CODES[actual_code]
+        expected_codes = (expected_code,) if isinstance(expected_code, Number) else expected_code
+        expected_codes_str = ", ".join('{} {}'.format(code, HTTP_CODES[code]) for code in expected_codes)
+        actual_code_str = HTTP_CODES[actual_code]
         msg = '''\
 {self.reason}.
   Operation     :  {method} {path}
-  Expected code :  {expected_code} {expected_code_str}
+  Expected code :  {expected_codes_str}
   Actual code   :  {actual_code} {actual_code_str}'''.format(**locals())
         super(OperationFailed, self).__init__(msg)
 
@@ -62,8 +64,21 @@ class Client(object):
         else:
             self.cwd += stripped_path
     def mkdir(self, path, safe=False):
-        expected_codes = 201 if not safe else (201, 301)
+        expected_codes = 201 if not safe else (201, 301, 302)
         self._send('MKCOL', path, expected_codes)
+    def mkdirs(self, path):
+        dirs = [d for d in path.split('/') if d]
+        if not dirs:
+            return
+        if path.startswith('/'):
+            dirs[0] = '/' + dirs[0]
+        old_cwd = self.cwd
+        try:
+            for dir in dirs:
+                self.mkdir(dir, safe=True)
+                self.cd(dir)
+        finally:
+            self.cd(old_cwd)
     def rmdir(self, path, safe=False):
         path = str(path).rstrip('/') + '/'
         expected_codes = 204 if not safe else (204, 404)
